==> odoo-addon-somconnexio-16.0.1.0.5.tar.gz: odoo-addon-somconnexio-16.0.1.0.5/odoo/addons/somconnexio/__manifest__.py <==
{
    "name": "Odoo Som Connexió customizations",
    "version": "16.0.1.0.5",
    "depends": [
        "account_asset_management",
        "account_banking_sepa_credit_transfer",
        "account_banking_sepa_direct_debit",
        "account_chart_update",
        "account_due_list",
        "account_financial_report",
        # "account_invoice_validation_queued",
        "account_payment_mode",
        "account_payment_order",
        "account_payment_partner",
        "account_payment_return",
        "account_payment_return_import_iso20022",
        "auth_oidc",
        "base_automation",
        "base_import_async",
        "base_rest_somconnexio",
        # "check_concurrent_update",
        "component_event",
        "contract",
        "contract_mandate",
        "contract_payment_mode",
        "crm_lead_product",
        "disable_login",
        "l10n_es",
        "l10n_es_account_asset",
        "l10n_es_account_statement_import_n43",
        "l10n_es_aeat",
        "l10n_es_aeat_mod111",
        "l10n_es_aeat_mod190",
        "l10n_es_aeat_mod303",
        "l10n_es_aeat_mod347",
        "l10n_es_aeat_mod349",
        "l10n_es_aeat_mod390",
        "l10n_es_igic",
        "l10n_es_mis_report",
        "l10n_es_partner",
        "l10n_es_toponyms",
        "mail",
        "mail_activity_board",
        "mail_activity_done",
        # Actualizar la version dependiendo de SEPA y descomentar
        # "mandate_partner_bank_creation",
        # "mass_editing",
        "mis_builder",
        "mis_builder_budget",
        "partner_firstname",
        "partner_priority",
        "product_pack",
        "account_payment_return_import",
        "queue_job",
        "sale_management",
        "server_environment",
        "social_media",
        "stock",
        # "web_decimal_numpad_dot",
        # "web_favicon",
        "web_chatter_position",
        "web_m2x_options",
        "web_no_bubble",
        "web_responsive",
        # "web_searchbar_full_width",
        "web_widget_open_tab",
        "partner_manual_rank",
    ],
    "external_dependencies": {
        "python": [
            "factory",
            "faker",
            "mm_proxy_python_client",
            "stdnum",
        ],
    },
    "author": "Coopdevs Treball SCCL, " "Som Connexió SCCL",
    "website": "https://coopdevs.org",
    "category": "Cooperative management",
    "license": "AGPL-3",
    "data": [
        "data/account_chart_template_data.xml",
        "data/account_group.xml",
        "data/account.account.template-sc.csv",
        "data/company.xml",
        "data/product_categories.xml",
        "data/crm_stage_data.xml",
        # TO CHANGE WITH ACCOUNT MOVE "views/account_invoice_view.xml",
        "views/res_partner_view.xml",
        "security/res_groups.xml",
        "data/service_supplier.xml",
        "data/service_technology.xml",
        "views/contract_view.xml",
        "views/service_technology_service_supplier.xml",
        "views/product_category_technology_supplier_view.xml",
        "views/previous_provider_view.xml",
        "views/crm_lead_line.xml",
        "views/crm_lead.xml",
        "views/crm_team_view.xml",
        "views/data_ba_view.xml",
        "views/menus.xml",
        "views/mobile_isp_info_view.xml",
        "views/broadband_isp_info_view.xml",
        "views/mis_budget_item_view.xml",
        "views/mobile_service_contract_info_view.xml",
        "views/adsl_service_contract_info_view.xml",
        "views/vodafone_fiber_service_contract_info.xml",
        "views/mm_fiber_service_contract_info.xml",
        "views/product_template_view.xml",
        "views/product_product_view.xml",
        "views/product_attribute_views.xml",
        "views/router_4G_service_contract_info.xml",
        "security/ir.model.access.csv",
        "crons/contract_compute_current_tariff_cron.xml",
        "data/service_technology_service_supplier.xml",
        "data/product_category_technology_supplier_data.xml",
        "data/product_attribute.xml",
        "data/product_attribute_value.xml",
        "data/product_template_data.xml",
        "data/product_template_attribute_line_data.xml",
        # Is Stock needed? It is only used in ADSL contracts
        # UNCOMMENT Pending of review the products "views/stock_move_line_view.xml",
        # UNCOMMENT Pending of review the products "views/stock_production_lot.xml",
        # UNCOMMENT Pending of review the products "data/product_pack_line.xml",
        "data/account_tax_group.xml",
        "data/account_tax.xml",
        "data/partner_action_tag_data.xml",
        "views/partner_action_tag_views.xml",
        "data/crm_team.xml",
        "data/account_journal.xml",
        "data/account_payment_mode.xml",
        "data/ir_sequence.xml",
        "data/res.users.xml",
        "data/previous_provider_data.xml",
        "data/ir_config_pararameter.xml",
        "data/contract_terminate_reason.xml",
        "data/contract_terminate_user_reason.xml",
        "data/fiber_signal_type_data.xml",
        "wizards/crm_lead_remesa/crm_lead_remesa.xml",
        "wizards/crm_leads_validate/crm_leads_validate.xml",
        "wizards/contract_iban_change/contract_iban_change.xml",
        "wizards/contract_holder_change/contract_holder_change.xml",
        "wizards/contract_address_change/contract_address_change.xml",
        "wizards/contract_tariff_change/contract_tariff_change.xml",
        "wizards/contract_one_shot_request/contract_one_shot_request.xml",
        "wizards/contract_mobile_check_consumption/contract_mobile_check_consumption.xml",  # noqa
        "wizards/contract_terminate/contract_terminate.xml",
        "wizards/move_line_add_to_payment_debit_order/move_line_add_to_payment_debit_order.xml",  # noqa
        "wizards/create_lead_from_partner/create_lead_from_partner.xml",
        "wizards/payment_order_confirm/payment_order_confirm.xml",
        "wizards/payment_order_generated_to_uploaded_queued/payment_order_generated_to_uploaded_queued.xml",  # noqa
        "wizards/account_financial_report/aged_partner_balance.xml",
        "wizards/account_financial_report/general_ledger.xml",
        "wizards/partner_email_change/partner_email_change.xml",
        "data/res_bank_data.xml",
        "reports/sim_sending_letter_template.xml",
        "reports/new_sim_sending_letter_template.xml",
        "reports/aged_partner_balance.xml",
        "data/partner_priority.xml",
        "reports/invoice_claim_1_template.xml",
        "reports/invoice_claim_1_capital_template.xml",
        "data/mail_activity_type.xml",
        "views/mail_activity_view.xml",
        "views/open_boards_activities.xml",
        "data/mis_report.xml",
        "reports/crm_lead_creation_email_template.xml",
        "reports/crm_lead_creation_manual_email_template.xml",
        "data/base_automation.xml",
        # "wizards/contract_invoice_payment/contract_invoice_payment.xml",
        "views/account_move_line.xml",
        "views/ir_action_view.xml",
        "wizards/import_payment_group/import_payment_group.xml",
        "views/payment_return_view.xml",
        "views/payment_return_import_view.xml",
        "wizards/account_payment_line_create/account_payment_line_create_view.xml",
        "wizards/contract_compensation/contract_compensation.xml",
        "views/xoln_fiber_service_contract_info.xml",
        "data/analytic_account.xml",
        "wizards/product_publish/product_publish.xml",
        "views/orange_fiber_service_contract_info.xml",
        "reports/mobile_can_be_linked_with_fiber_mail_template.xml",
        "reports/mobile_linked_with_fiber_mail_template.xml",
        "views/aeat_report_view.xml",
        "views/account_asset_view.xml",
        "views/data_range_view.xml",
        "wizards/crm_lead_add_mobile_line/crm_lead_add_mobile_line.xml",
        "data/xoln_project_data.xml",
        "data/products/mobile.xml",
        "data/products/fibra.xml",
        "data/products/adsl.xml",
        "data/products/broadband.xml",
        "data/products/packs.xml",
        "data/products/international_mobile.xml",
        "data/products/invoice_subscription.xml",
        "data/products/additional_data_mobile.xml",
        "data/products/broadband_one_shot.xml",
        "data/products/SMS.xml",
        "data/products/SIM.xml",
        "data/products/router.xml",
        "data/products/router4G.xml",
        "data/products/invoice_consumptions.xml",
    ],
    "demo": [
        "demo/partner.xml",
        "demo/contract/contract.xml",
        "demo/contract/contract_pack.xml",
        "demo/contract/contract_shared_data.xml",
        "demo/product.pricelist.csv",
        "demo/product.product.csv",
    ],
    "qweb": [
        "static/src/xml/activity.xml",
        "static/src/xml/mail_chatter_buttons.xml",
    ],
    "assets": {
        "web.assets_backend": [
            "somconnexio/static/src/fields/many2many_tags_contract_email.js",
            "somconnexio/static/src/fields/many2many_tags_contract_email.xml",
            # "somconnexio/static/src/models/activity_box_view.js",
        ],
    },
    "post_load": "post_load_hook",
}

==> odoo-addon-somconnexio-16.0.1.0.6.tar.gz: odoo-addon-somconnexio-16.0.1.0.6/odoo/addons/somconnexio/__manifest__.py <==
{
    "name": "Odoo Som Connexió customizations",
    "version": "16.0.1.0.6",
    "depends": [
        "account_asset_management",
        "account_banking_sepa_credit_transfer",
        "account_banking_sepa_direct_debit",
        "account_chart_update",
        "account_due_list",
        "account_financial_report",
        # "account_invoice_validation_queued",
        "account_payment_mode",
        "account_payment_order",
        "account_payment_partner",
        "account_payment_return",
        "account_payment_return_import_iso20022",
        "auth_oidc",
        "base_automation",
        "base_import_async",
        "base_rest_somconnexio",
        # "check_concurrent_update",
        "component_event",
        "contract",
        "contract_mandate",
        "contract_payment_mode",
        "crm_lead_product",
        "disable_login",
        "l10n_es",
        "l10n_es_account_asset",
        "l10n_es_account_statement_import_n43",
        "l10n_es_aeat",
        "l10n_es_aeat_mod111",
        "l10n_es_aeat_mod190",
        "l10n_es_aeat_mod303",
        "l10n_es_aeat_mod347",
        "l10n_es_aeat_mod349",
        "l10n_es_aeat_mod390",
        "l10n_es_igic",
        "l10n_es_mis_report",
        "l10n_es_partner",
        "l10n_es_toponyms",
        "mail",
        "mail_activity_board",
        "mail_activity_done",
        # Actualizar la version dependiendo de SEPA y descomentar
        # "mandate_partner_bank_creation",
        # "mass_editing",
        "mis_builder",
        "mis_builder_budget",
        "partner_firstname",
        "partner_priority",
        "product_pack",
        "account_payment_return_import",
        "queue_job",
        "sale_management",
        "server_environment",
        "social_media",
        "stock",
        # "web_decimal_numpad_dot",
        # "web_favicon",
        "web_chatter_position",
        "web_m2x_options",
        "web_no_bubble",
        "web_responsive",
        # "web_searchbar_full_width",
        "web_widget_open_tab",
        "partner_manual_rank",
    ],
    "external_dependencies": {
        "python": [
            "factory",
            "faker",
            "mm_proxy_python_client",
            "stdnum",
        ],
    },
    "author": "Coopdevs Treball SCCL, " "Som Connexió SCCL",
    "website": "https://coopdevs.org",
    "category": "Cooperative management",
    "license": "AGPL-3",
    "data": [
        "data/account_chart_template_data.xml",
        "data/account_group.xml",
        "data/account.account.template-sc.csv",
        "data/company.xml",
        "data/product_categories.xml",
        "data/crm_stage_data.xml",
        # TO CHANGE WITH ACCOUNT MOVE "views/account_invoice_view.xml",
        "views/res_partner_view.xml",
        "security/res_groups.xml",
        "data/service_supplier.xml",
        "data/service_technology.xml",
        "views/contract_view.xml",
        "views/service_technology_service_supplier.xml",
        "views/product_category_technology_supplier_view.xml",
        "views/previous_provider_view.xml",
        "views/crm_lead_line.xml",
        "views/crm_lead.xml",
        "views/crm_team_view.xml",
        "views/data_ba_view.xml",
        "views/menus.xml",
        "views/mobile_isp_info_view.xml",
        "views/broadband_isp_info_view.xml",
        "views/mis_budget_item_view.xml",
        "views/mobile_service_contract_info_view.xml",
        "views/adsl_service_contract_info_view.xml",
        "views/vodafone_fiber_service_contract_info.xml",
        "views/mm_fiber_service_contract_info.xml",
        "views/product_template_view.xml",
        "views/product_product_view.xml",
        "views/product_attribute_views.xml",
        "views/router_4G_service_contract_info.xml",
        "security/ir.model.access.csv",
        "crons/contract_compute_current_tariff_cron.xml",
        "data/service_technology_service_supplier.xml",
        "data/product_category_technology_supplier_data.xml",
        "data/product_attribute.xml",
        "data/product_attribute_value.xml",
        "data/product_template_data.xml",
        "data/product_template_attribute_line_data.xml",
        # Is Stock needed? It is only used in ADSL contracts
        # UNCOMMENT Pending of review the products "views/stock_move_line_view.xml",
        # UNCOMMENT Pending of review the products "views/stock_production_lot.xml",
        # UNCOMMENT Pending of review the products "data/product_pack_line.xml",
        "data/account_tax_group.xml",
        "data/account_tax.xml",
        "data/partner_action_tag_data.xml",
        "views/partner_action_tag_views.xml",
        "data/crm_team.xml",
        "data/account_journal.xml",
        "data/account_payment_mode.xml",
        "data/ir_sequence.xml",
        "data/res.users.xml",
        "data/previous_provider_data.xml",
        "data/ir_config_pararameter.xml",
        "data/contract_terminate_reason.xml",
        "data/contract_terminate_user_reason.xml",
        "data/fiber_signal_type_data.xml",
        "wizards/crm_lead_remesa/crm_lead_remesa.xml",
        "wizards/crm_leads_validate/crm_leads_validate.xml",
        "wizards/contract_iban_change/contract_iban_change.xml",
        "wizards/contract_holder_change/contract_holder_change.xml",
        "wizards/contract_address_change/contract_address_change.xml",
        "wizards/contract_tariff_change/contract_tariff_change.xml",
        "wizards/contract_one_shot_request/contract_one_shot_request.xml",
        "wizards/contract_mobile_check_consumption/contract_mobile_check_consumption.xml",  # noqa
        "wizards/contract_terminate/contract_terminate.xml",
        "wizards/move_line_add_to_payment_debit_order/move_line_add_to_payment_debit_order.xml",  # noqa
        "wizards/create_lead_from_partner/create_lead_from_partner.xml",
        "wizards/payment_order_confirm/payment_order_confirm.xml",
        "wizards/payment_order_generated_to_uploaded_queued/payment_order_generated_to_uploaded_queued.xml",  # noqa
        "wizards/account_financial_report/aged_partner_balance.xml",
        "wizards/account_financial_report/general_ledger.xml",
        "wizards/partner_email_change/partner_email_change.xml",
        "data/res_bank_data.xml",
        "reports/sim_sending_letter_template.xml",
        "reports/new_sim_sending_letter_template.xml",
        "reports/aged_partner_balance.xml",
        "data/partner_priority.xml",
        "reports/invoice_claim_1_template.xml",
        "reports/invoice_claim_1_capital_template.xml",
        "data/mail_activity_type.xml",
        "views/mail_activity_view.xml",
        "views/open_boards_activities.xml",
        "data/mis_report.xml",
        "reports/crm_lead_creation_email_template.xml",
        "reports/crm_lead_creation_manual_email_template.xml",
        "data/base_automation.xml",
        # "wizards/contract_invoice_payment/contract_invoice_payment.xml",
        "views/account_move_line.xml",
        "views/ir_action_view.xml",
        "wizards/import_payment_group/import_payment_group.xml",
        "views/payment_return_view.xml",
        "views/payment_return_import_view.xml",
        "wizards/account_payment_line_create/account_payment_line_create_view.xml",
        "wizards/contract_compensation/contract_compensation.xml",
        "views/xoln_fiber_service_contract_info.xml",
        "data/analytic_account.xml",
        "wizards/product_publish/product_publish.xml",
        "views/orange_fiber_service_contract_info.xml",
        "reports/mobile_can_be_linked_with_fiber_mail_template.xml",
        "reports/mobile_linked_with_fiber_mail_template.xml",
        "views/aeat_report_view.xml",
        "views/account_asset_view.xml",
        "views/data_range_view.xml",
        "wizards/crm_lead_add_mobile_line/crm_lead_add_mobile_line.xml",
        "data/xoln_project_data.xml",
        "data/products/mobile.xml",
        "data/products/fibra.xml",
        "data/products/adsl.xml",
        "data/products/broadband.xml",
        "data/products/packs.xml",
        "data/products/international_mobile.xml",
        "data/products/invoice_subscription.xml",
        "data/products/additional_data_mobile.xml",
        "data/products/broadband_one_shot.xml",
        "data/products/SMS.xml",
        "data/products/SIM.xml",
        "data/products/router.xml",
        "data/products/router4G.xml",
        "data/products/invoice_consumptions.xml",
    ],
    "demo": [
        "demo/partner.xml",
        "demo/contract/contract.xml",
        "demo/contract/contract_pack.xml",
        "demo/contract/contract_shared_data.xml",
        "demo/product.pricelist.csv",
        "demo/product.product.csv",
    ],
    "qweb": [
        "static/src/xml/activity.xml",
        "static/src/xml/mail_chatter_buttons.xml",
    ],
    "assets": {
        "web.assets_backend": [
            "somconnexio/static/src/fields/many2many_tags_contract_email.js",
            "somconnexio/static/src/fields/many2many_tags_contract_email.xml",
            "somconnexio/static/src/models/activity_box_view.js",
        ],
    },
    "post_load": "post_load_hook",
}
